Module builder

Module builder 

A Builder enables you to build instructions.

Structs

Builder
All build_* methods return a Result<_, BuilderError> type containing either the returned value or some error. Those methods all may return BuilderError::UnsetPosition if a position_* method has not yet been called, in addition to any other possibility.

Enums

BuilderError
Errors that can be generated by the Builder. All build_* methods return a Result<_, BuilderError>, which must be handled.
CmpxchgOrderingError