Module module

Module module 

A Module represents a single code compilation unit.

Structs

FunctionIterator
Iterate over all FunctionValues in an llvm module
GlobalIterator
Iterate over all GlobalValues in an llvm module
Module
Represents a reference to an LLVM Module. The underlying module will be disposed when dropping this object.

Enums

FlagBehavior
Defines the operational behavior for a module wide flag. This documentation comes directly from the LLVM docs
Linkage
This enum defines how to link a global variable or function in a module. The variant documentation is mostly taken straight from LLVM’s own documentation except for some minor clarification.