pub struct VectorType<'ctx> { /* private fields */ }Expand description
A VectorType is the type of a multiple value SIMD constant or variable.
Implementations
Sourceimpl<'ctx> VectorType<'ctx>
impl<'ctx> VectorType<'ctx>
Sourcepub unsafe fn new(vector_type: LLVMTypeRef) -> Self
pub unsafe fn new(vector_type: LLVMTypeRef) -> Self
Sourcepub fn size_of(self) -> Option<IntValue<'ctx>>
pub fn size_of(self) -> Option<IntValue<'ctx>>
Gets the size of this VectorType. Value may vary depending on the target architecture.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let f32_vec_type_size = f32_vec_type.size_of();Sourcepub fn get_size(self) -> u32
pub fn get_size(self) -> u32
Gets the size of this VectorType.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vector_type = f32_type.vec_type(3);
assert_eq!(f32_vector_type.get_size(), 3);
assert_eq!(f32_vector_type.get_element_type().into_float_type(), f32_type);Sourcepub fn const_vector<V: BasicValue<'ctx>>(values: &[V]) -> VectorValue<'ctx>
pub fn const_vector<V: BasicValue<'ctx>>(values: &[V]) -> VectorValue<'ctx>
Creates a constant VectorValue.
Example
use inkwell::context::Context;
use inkwell::types::VectorType;
let context = Context::create();
let f32_type = context.f32_type();
let f32_val = f32_type.const_float(0.);
let f32_val2 = f32_type.const_float(2.);
let f32_vec_val = VectorType::const_vector(&[f32_val, f32_val2]);
assert!(f32_vec_val.is_constant_vector());Sourcepub fn const_zero(self) -> VectorValue<'ctx>
pub fn const_zero(self) -> VectorValue<'ctx>
Creates a constant zero value of this VectorType.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(7);
let f32_vec_zero = f32_vec_type.const_zero();Sourcepub fn print_to_string(self) -> LLVMString
pub fn print_to_string(self) -> LLVMString
Print the definition of a VectorType to LLVMString.
Sourcepub fn get_undef(self) -> VectorValue<'ctx>
pub fn get_undef(self) -> VectorValue<'ctx>
Creates an undefined instance of a VectorType.
Example
use inkwell::context::Context;
use inkwell::AddressSpace;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let f32_vec_undef = f32_vec_type.get_undef();
assert!(f32_vec_undef.is_undef());Sourcepub fn get_poison(self) -> VectorValue<'ctx>
pub fn get_poison(self) -> VectorValue<'ctx>
Creates a poison instance of a VectorType.
Example
use inkwell::context::Context;
use inkwell::AddressSpace;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let f32_vec_poison = f32_vec_type.get_undef();
assert!(f32_vec_poison.is_undef());Sourcepub fn get_element_type(self) -> BasicTypeEnum<'ctx>
pub fn get_element_type(self) -> BasicTypeEnum<'ctx>
Gets the element type of this VectorType.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vector_type = f32_type.vec_type(3);
assert_eq!(f32_vector_type.get_size(), 3);
assert_eq!(f32_vector_type.get_element_type().into_float_type(), f32_type);Sourcepub fn ptr_type(self, address_space: AddressSpace) -> PointerType<'ctx>
👎Deprecated: Starting from version 15.0, LLVM doesn’t differentiate between pointer types. Use Context::ptr_type instead.
pub fn ptr_type(self, address_space: AddressSpace) -> PointerType<'ctx>
Starting from version 15.0, LLVM doesn’t differentiate between pointer types. Use Context::ptr_type instead.
Creates a PointerType with this VectorType for its element type.
Example
use inkwell::context::Context;
use inkwell::AddressSpace;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let f32_vec_ptr_type = f32_vec_type.ptr_type(AddressSpace::default());
#[cfg(feature = "typed-pointers")]
assert_eq!(f32_vec_ptr_type.get_element_type().into_vector_type(), f32_vec_type);Sourcepub fn fn_type(
self,
param_types: &[BasicMetadataTypeEnum<'ctx>],
is_var_args: bool,
) -> FunctionType<'ctx>
pub fn fn_type( self, param_types: &[BasicMetadataTypeEnum<'ctx>], is_var_args: bool, ) -> FunctionType<'ctx>
Creates a FunctionType with this VectorType for its return type.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let fn_type = f32_vec_type.fn_type(&[], false);Sourcepub fn array_type(self, size: u32) -> ArrayType<'ctx>
pub fn array_type(self, size: u32) -> ArrayType<'ctx>
Creates an ArrayType with this VectorType for its element type.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(3);
let f32_vec_array_type = f32_vec_type.array_type(3);
assert_eq!(f32_vec_array_type.len(), 3);
assert_eq!(f32_vec_array_type.get_element_type().into_vector_type(), f32_vec_type);Sourcepub fn const_array(self, values: &[VectorValue<'ctx>]) -> ArrayValue<'ctx>
pub fn const_array(self, values: &[VectorValue<'ctx>]) -> ArrayValue<'ctx>
Creates a constant ArrayValue.
Example
use inkwell::context::Context;
use inkwell::types::VectorType;
let context = Context::create();
let f32_type = context.f32_type();
let f32_val = f32_type.const_float(0.);
let f32_val2 = f32_type.const_float(2.);
let f32_vec_type = f32_type.vec_type(2);
let f32_vec_val = VectorType::const_vector(&[f32_val, f32_val2]);
let f32_array = f32_vec_type.const_array(&[f32_vec_val, f32_vec_val]);
assert!(f32_array.is_const());Sourcepub fn get_context(self) -> ContextRef<'ctx>
pub fn get_context(self) -> ContextRef<'ctx>
Gets a reference to the Context this VectorType was created in.
Example
use inkwell::context::Context;
let context = Context::create();
let f32_type = context.f32_type();
let f32_vec_type = f32_type.vec_type(7);
assert_eq!(f32_vec_type.get_context(), context);Trait Implementations
Sourceimpl<'ctx> AnyType<'ctx> for VectorType<'ctx>
impl<'ctx> AnyType<'ctx> for VectorType<'ctx>
Sourcefn as_any_type_enum(&self) -> AnyTypeEnum<'ctx>
fn as_any_type_enum(&self) -> AnyTypeEnum<'ctx>
AnyTypeEnum that represents the current type.Sourcefn print_to_string(&self) -> LLVMString
fn print_to_string(&self) -> LLVMString
LLVMString.Sourceimpl AsTypeRef for VectorType<'_>
impl AsTypeRef for VectorType<'_>
Sourcefn as_type_ref(&self) -> LLVMTypeRef
fn as_type_ref(&self) -> LLVMTypeRef
Sourceimpl<'ctx> BasicType<'ctx> for VectorType<'ctx>
impl<'ctx> BasicType<'ctx> for VectorType<'ctx>
Sourcefn as_basic_type_enum(&self) -> BasicTypeEnum<'ctx>
fn as_basic_type_enum(&self) -> BasicTypeEnum<'ctx>
BasicTypeEnum that represents the current type.Sourcefn fn_type(
&self,
param_types: &[BasicMetadataTypeEnum<'ctx>],
is_var_args: bool,
) -> FunctionType<'ctx>
fn fn_type( &self, param_types: &[BasicMetadataTypeEnum<'ctx>], is_var_args: bool, ) -> FunctionType<'ctx>
Sourcefn is_sized(&self) -> bool
fn is_sized(&self) -> bool
BasicType is sized or not.
For example, opaque structs are unsized. Read moreSourcefn size_of(&self) -> Option<IntValue<'ctx>>
fn size_of(&self) -> Option<IntValue<'ctx>>
BasicType. Value may vary depending on the target architecture. Read moreSourcefn get_alignment(&self) -> IntValue<'ctx>
fn get_alignment(&self) -> IntValue<'ctx>
BasicType. Value may vary depending on the target architecture. Read moreSourcefn array_type(&self, size: u32) -> ArrayType<'ctx>
fn array_type(&self, size: u32) -> ArrayType<'ctx>
Sourcefn ptr_type(&self, address_space: AddressSpace) -> PointerType<'ctx>
fn ptr_type(&self, address_space: AddressSpace) -> PointerType<'ctx>
Starting from version 15.0, LLVM doesn’t differentiate between pointer types. Use Context::ptr_type instead.
Sourceimpl<'ctx> Clone for VectorType<'ctx>
impl<'ctx> Clone for VectorType<'ctx>
Sourcefn clone(&self) -> VectorType<'ctx>
fn clone(&self) -> VectorType<'ctx>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl<'ctx> Copy for VectorType<'ctx>
Sourceimpl<'ctx> Debug for VectorType<'ctx>
impl<'ctx> Debug for VectorType<'ctx>
Sourceimpl Display for VectorType<'_>
impl Display for VectorType<'_>
impl<'ctx> Eq for VectorType<'ctx>
Sourceimpl<'ctx> FloatMathType<'ctx> for VectorType<'ctx>
impl<'ctx> FloatMathType<'ctx> for VectorType<'ctx>
Sourcetype ValueType = VectorValue<'ctx>
type ValueType = VectorValue<'ctx>
Sourcetype MathConvType = VectorType<'ctx>
type MathConvType = VectorType<'ctx>
Sourceimpl<'ctx> From<VectorType<'ctx>> for AnyTypeEnum<'ctx>
impl<'ctx> From<VectorType<'ctx>> for AnyTypeEnum<'ctx>
Sourcefn from(value: VectorType<'_>) -> AnyTypeEnum<'_>
fn from(value: VectorType<'_>) -> AnyTypeEnum<'_>
Sourceimpl<'ctx> From<VectorType<'ctx>> for BasicTypeEnum<'ctx>
impl<'ctx> From<VectorType<'ctx>> for BasicTypeEnum<'ctx>
Sourcefn from(value: VectorType<'_>) -> BasicTypeEnum<'_>
fn from(value: VectorType<'_>) -> BasicTypeEnum<'_>
Sourceimpl<'ctx> From<VectorType<'ctx>> for BasicMetadataTypeEnum<'ctx>
impl<'ctx> From<VectorType<'ctx>> for BasicMetadataTypeEnum<'ctx>
Sourcefn from(value: VectorType<'_>) -> BasicMetadataTypeEnum<'_>
fn from(value: VectorType<'_>) -> BasicMetadataTypeEnum<'_>
Sourceimpl<'ctx> IntMathType<'ctx> for VectorType<'ctx>
impl<'ctx> IntMathType<'ctx> for VectorType<'ctx>
Sourcetype ValueType = VectorValue<'ctx>
type ValueType = VectorValue<'ctx>
Sourcetype MathConvType = VectorType<'ctx>
type MathConvType = VectorType<'ctx>
Sourcetype PtrConvType = VectorType<'ctx>
type PtrConvType = VectorType<'ctx>
Sourceimpl<'ctx> PartialEq for VectorType<'ctx>
impl<'ctx> PartialEq for VectorType<'ctx>
Sourcefn eq(&self, other: &VectorType<'ctx>) -> bool
fn eq(&self, other: &VectorType<'ctx>) -> bool
self and other values to be equal, and is used by ==.