pub unsafe trait BasicValue<'ctx>: AnyValue<'ctx> {
// Provided methods
fn as_basic_value_enum(&self) -> BasicValueEnum<'ctx> { ... }
fn as_instruction_value(&self) -> Option<InstructionValue<'ctx>> { ... }
fn get_first_use(&self) -> Option<BasicValueUse<'ctx>> { ... }
fn set_name(&self, name: &str) { ... }
fn is_const(&self) -> bool { ... }
}Expand description
Represents a basic value, which can be used both by itself, or in an AggregateValue.
Provided Methods
Sourcefn as_basic_value_enum(&self) -> BasicValueEnum<'ctx>
fn as_basic_value_enum(&self) -> BasicValueEnum<'ctx>
Returns an enum containing a typed version of the BasicValue.
Sourcefn as_instruction_value(&self) -> Option<InstructionValue<'ctx>>
fn as_instruction_value(&self) -> Option<InstructionValue<'ctx>>
Most BasicValues are the byproduct of an instruction
and so are convertible into an InstructionValue
fn get_first_use(&self) -> Option<BasicValueUse<'ctx>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".